@@ -1,13 +1,14 @@
-from fa_purity.frozen import (
-    freeze,
+from fa_purity import (
+    FrozenTools,
 )
-from fa_purity.json_2.primitive import (
+from fa_purity._core.unsafe import (
+    Unsafe,
+)
+from fa_purity.json import (
     JsonPrimitiveFactory,
-    Primitive,
-)
-from fa_purity.json_2.value import (
     JsonValue,
     JsonValueFactory,
+    Primitive,
     Unfolder,
 )
 
@@ -17,22 +18,21 @@ def _prim_value(value: Primitive) -> JsonValue:
 
 
 def test_from_any() -> None:
-    json_obj = freeze(
+    json_obj = FrozenTools.freeze(
         {
             "foo": JsonValue.from_json(
-                freeze(
+                FrozenTools.freeze(
                     {
-                        "nested": JsonValue.from_list(
-                            tuple([_prim_value("hi"), _prim_value(99)])
-                        ),
-                    }
-                )
-            )
-        }
+                        "nested": JsonValue.from_list((_prim_value("hi"), _prim_value(99))),
+                    },
+                ),
+            ),
+        },
     )
     json_obj_from_raw = (
         JsonValueFactory.from_any({"foo": {"nested": ["hi", 99]}})
         .bind(Unfolder.to_json)
-        .unwrap()
+        .alt(Unsafe.raise_exception)
+        .to_union()
     )
     assert json_obj == json_obj_from_raw
