@@ -1,25 +1,22 @@
-from fa_purity.frozen import (
-    FrozenList,
-)
-from fa_purity.pure_iter.core import (
-    PureIter,
-)
 from typing import (
     TypeVar,
 )
 
+from fa_purity import (
+    FrozenList,
+    PureIter,
+)
+
 _T = TypeVar("_T")
 
 
-def to_tuple(piter: PureIter[_T], limit: int) -> FrozenList[_T]:
-    n_items = 0
-    items = []
-    for i in piter:
-        n_items += 1
-        items.append(i)
-        if n_items >= limit:
+def to_tuple(items: PureIter[_T], limit: int) -> FrozenList[_T]:
+    result = []
+    for n, i in enumerate(items):
+        result.append(i)
+        if n + 1 >= limit:
             break
-    return tuple(items)
+    return tuple(result)
 
 
 def assert_immutability(piter: PureIter[_T], only_count: bool = False) -> None:
