@@ -1,8 +1,5 @@
-from fa_purity.pure_iter.factory import (
-    from_flist,
-    from_range,
-    infinite_gen,
-    infinite_range,
+from fa_purity import (
+    PureIterFactory,
 )
 from tests.pure_iter._utils import (
     assert_immutability,
@@ -13,18 +10,18 @@ from tests.pure_iter._utils import (
 
 def test_flist() -> None:
     items = tuple(range(10))
-    assert_immutability(from_flist(items))
+    assert_immutability(PureIterFactory.from_list(items))
 
 
 def test_range() -> None:
-    assert_immutability(from_range(range(10)))
+    assert_immutability(PureIterFactory.from_range(range(10)))
 
 
 def test_inf_range() -> None:
-    assert_immutability_inf(infinite_range(3, 5))
+    assert_immutability_inf(PureIterFactory.infinite_range(3, 5))
 
 
 def test_infinite_gen() -> None:
-    items = infinite_gen(lambda x: x + 1, 0)
+    items = PureIterFactory.infinite_gen(lambda x: x + 1, 0)
     assert_immutability_inf(items)
     assert to_tuple(items, 10) == tuple(range(10))
