@@ -1,17 +1,10 @@
-from fa_purity.cmd import (
-    Cmd,
-)
-from fa_purity.pure_iter.factory import (
-    from_flist,
-    from_range,
-)
-from fa_purity.pure_iter.transform import (
-    chain,
-    consume,
-    filter_opt,
-    until_none,
-)
 import pytest
+
+from fa_purity import (
+    Cmd,
+    PureIterFactory,
+    PureIterTransform,
+)
 from tests.pure_iter._utils import (
     assert_immutability,
 )
@@ -19,8 +12,8 @@ from tests.pure_iter._utils import (
 
 def test_chain() -> None:
     base = (4, 78, 6)
-    items = from_range(range(5)).map(lambda i: from_flist(base))
-    chained = chain(items)
+    items = PureIterFactory.from_range(range(5)).map(lambda _: PureIterFactory.from_list(base))
+    chained = PureIterTransform.chain(items)
     assert_immutability(chained)
     assert tuple(chained) == base * 5
 
@@ -31,11 +24,11 @@ def test_consume() -> None:
     def _mutate(num: int) -> None:
         mutable_obj[0] = num
 
-    items = from_flist(tuple(range(5))).map(
-        lambda i: Cmd.from_cmd(lambda: _mutate(i))
+    items = PureIterFactory.from_list(tuple(range(5))).map(
+        lambda i: Cmd.wrap_impure(lambda: _mutate(i)),
     )
     assert_immutability(items, True)
-    cmd = consume(items)
+    cmd = PureIterTransform.consume(items)
     assert mutable_obj[0] == 0
 
     def _verify(_: None) -> None:
@@ -46,14 +39,14 @@ def test_consume() -> None:
 
 
 def test_filter_opt() -> None:
-    items = tuple((0, 1, 2, 3, None, 4, 5, 6))
-    result = filter_opt(from_flist(items))
+    items = (0, 1, 2, 3, None, 4, 5, 6)
+    result = PureIterTransform.filter_opt(PureIterFactory.from_list(items))
     assert_immutability(result)
     assert tuple(result) == tuple(range(7))
 
 
 def test_until_none() -> None:
-    items = tuple((0, 1, 2, 3, None, 4, 5, 6))
-    result = until_none(from_flist(items))
+    items = (0, 1, 2, 3, None, 4, 5, 6)
+    result = PureIterTransform.until_none(PureIterFactory.from_list(items))
     assert_immutability(result)
     assert tuple(result) == tuple(range(4))
