@@ -1,6 +1,5 @@
-from fa_purity.pure_iter.factory import (
-    from_range,
-    infinite_range,
+from fa_purity import (
+    PureIterFactory,
 )
 from tests.pure_iter._utils import (
     assert_immutability,
@@ -9,7 +8,7 @@ from tests.pure_iter._utils import (
 
 
 def test_use_case_1() -> None:
-    items = from_range(range(0, 10))
+    items = PureIterFactory.from_range(range(10))
     mapped = items.map(lambda i: i + 2)
     assert mapped.to_list() == tuple(range(2, 12))
     r = items.map(lambda x: x * 2).chunked(3)
@@ -20,7 +19,7 @@ def test_use_case_1() -> None:
 
 
 def test_inf() -> None:
-    items = infinite_range(4, 10)
+    items = PureIterFactory.infinite_range(4, 10)
     for n, v in enumerate(items):
         assert v == 4 + (n * 10)
         if n > 15:
