@@ -1,4 +1,4 @@
-from fa_purity.union import (
+from fa_purity import (
     Coproduct,
     CoproductFactory,
     CoproductTransform,
